PS3="special prompt!>>"
exit=0;
chmod a+x *.sh
select opt in *.sh "exit" ; do 
case "$opt" in
"case.sh") ./case.sh ;;
*".sh"   ) echo "Selected: $opt ($REPLY)" ; ./$opt ;;
"exit"   ) exit=1 ; break ;;
*        ) echo "error!" ;;
esac 
if ((exit==1)) 
	then break ;
fi
done

